@@ -188,9 +188,6 @@ static GtkWidget * create_desktop_menu (GtkWidget *m,
 
 static void add_bonobo_applet (GtkWidget  *widget, const char *iid);
 
-static void add_kde_submenu (GtkWidget *root_menu,
-			     gboolean fake_submenus,
-			     gboolean launcher_add);
 static void add_distribution_submenu (GtkWidget *root_menu,
 				      gboolean fake_submenus,
 				      gboolean launcher_add);
@@ -198,11 +195,6 @@ static void add_distribution_submenu (GtkWidget *root_menu,
 static GtkWidget * create_add_launcher_menu (GtkWidget *menu,
 					     gboolean fake_submenus);
 
-static void setup_stock_menu_item     (GtkWidget   *item,
-				       GtkIconSize  icon_size,
-				       const char  *stock_id,
-				       const char  *title,
-				       gboolean     invisible_mnemonic);
 static gboolean panel_menu_key_press_handler (GtkWidget   *widget,
 					      GdkEventKey *event);
 static void         make_add_submenu   (GtkWidget             *menu,
@@ -356,6 +348,7 @@ activate_app_def (GtkWidget  *menuitem,
 			panel_error_dialog (menuitem_to_screen (menuitem),
 					    "cannot_launch_entry",
 					    _("Cannot launch entry"),
+					    "%s",
 					    error->message);
 
 			g_clear_error (&error);
@@ -367,6 +360,7 @@ activate_app_def (GtkWidget  *menuitem,
 		panel_error_dialog (menuitem_to_screen (menuitem),
 				    "cannot_load_entry",
 				    _("Cannot load entry"),
+				    "%s",
 				    error->message);
 
 		g_clear_error (&error);
@@ -1066,8 +1060,9 @@ remove_menuitem (GtkWidget *widget, ShowItemMenu *sim)
 		panel_error_dialog (menuitem_to_screen (sim->menuitem),
 				    "cannot_remove_menu_item",
 				    _("Cannot remove menu item %s"),
-				    gnome_vfs_result_to_string (result),
-				    esc);
+				    "%s",
+				    esc,
+				    gnome_vfs_result_to_string (result));
 
 		g_free (esc);
 		return;
@@ -1161,6 +1156,7 @@ add_to_run_dialog (GtkWidget    *widget,
 		panel_error_dialog (menuitem_to_screen (sim->menuitem),
 				    "cannot_load_entry",
 				    _("Cannot load entry"),
+				    "%s",
 				    error->message);
 
 		g_clear_error (&error);
@@ -1187,6 +1183,7 @@ show_help_on (GtkWidget    *widget,
 			panel_error_dialog (screen,
 					    "cannot_show_gnome_kde_help",
 					    _("Cannot display help document"),
+					    "%s",
 					    error->message);
 
 			g_clear_error (&error);
@@ -1199,6 +1196,7 @@ show_help_on (GtkWidget    *widget,
 		panel_error_dialog (screen,
 				    "cannot_load_entry",
 				    _("Cannot load entry"),
+				    "%s",
 				    error->message);
 
 		g_clear_error (&error);
@@ -1224,88 +1222,91 @@ add_app_to_panel (GtkWidget    *item,
 }
 
 
-static void
-add_drawers_from_dir (const char *dirname, const char *name,
-		      int pos, PanelWidget *panel)
+static inline gboolean
+vfs_text_uri_exists (const char *text_uri)
 {
-	QuickDesktopItem *item_info;
-	char *dentry_name;
-	const char *subdir_name;
-	char *pixmap_name;
+	GnomeVFSURI *uri;
+	gboolean     retval;
 
-	dentry_name = g_build_path ("/",
-				    dirname,
-				    ".directory",
-				    NULL);
-	item_info = quick_desktop_item_load_uri (dentry_name,
-						 NULL /* expected_type */,
-						 FALSE /* run_tryexec */);
-	g_free (dentry_name);
+	uri = gnome_vfs_uri_new (text_uri);
+	retval = gnome_vfs_uri_exists (uri);
+	gnome_vfs_uri_unref (uri);
 
-	if (name == NULL)
-		subdir_name = item_info != NULL ? item_info->name : NULL;
-	else
-		subdir_name = name;
-	pixmap_name = item_info != NULL ? item_info->icon : NULL;
-
-	panel_drawer_create (panel->toplevel,
-			     pos,
-			     pixmap_name,
-			     pixmap_name != NULL,
-			     subdir_name);
-
-#ifdef FIXME_FOR_NEW_CONFIG
-	Drawer *drawer;
-	PanelWidget *newpanel;
-	char *filename = NULL;
-	GSList *list, *li;
-
-	newpanel = panel_toplevel_get_panel_widget (drawer->toplevel);
-
-	list = get_mfiles_from_menudir (dirname, NULL /* sorted */);
-	for(li = list; li!= NULL; li = li->next) {
-		MFile *mfile = li->data;
-
-		g_free (filename);
-		filename = g_build_filename (dirname, mfile->name, NULL);
-
-		if ( ! mfile->verified) {
-			continue;
-		}
-
-		if (mfile->is_dir) {
-			add_drawers_from_dir (filename, NULL, G_MAXINT/2,
-					      newpanel);
-			continue;
-		}
-			
-		if ((g_str_has_suffix (mfile->name, ".desktop") ||
-		     g_str_has_suffix (mfile->name, ".kdelnk")) &&
-		    g_file_test (filename, G_FILE_TEST_EXISTS))
-			panel_launcher_create (newpanel->toplevel, G_MAXINT/2, filename);
-	}
-	g_free (filename);
-
-	free_mfile_list (list);
-#endif
+	return retval;
 }
 
-/*add a drawer with the contents of a menu to the panel*/
 static void
-add_menudrawer_to_panel(GtkWidget *widget, gpointer data)
+add_drawers_from_dir (const char  *dirname,
+		      const char  *name,
+		      int          pos,
+		      const char  *toplevel_id)
 {
-	MenuFinfo *mf = data;
-	PanelWidget *panel = menu_get_panel (widget);
-	PanelData *pd;
-	int insertion_pos = -1;
+	QuickDesktopItem *item_info;
+	GSList           *mfiles, *l;
+	const char       *subdir_name;
+	char             *dentry_name;
+	char             *pixmap_name;
+	char             *uri;
+	char             *attached_toplevel_id;
 
-	g_return_if_fail (mf != 0);
+	dentry_name = g_build_path ("/", dirname, ".directory", NULL);
+	item_info = quick_desktop_item_load_uri (dentry_name, NULL, FALSE);
+	g_free (dentry_name);
+
+	subdir_name = name ? name : (item_info ? item_info->name : NULL);
+	pixmap_name = item_info ? item_info->icon : NULL;
+
+	attached_toplevel_id = panel_drawer_create_with_id (toplevel_id,
+							    pos,
+							    pixmap_name,
+							    pixmap_name != NULL,
+							    subdir_name);
+	if (!attached_toplevel_id)
+		return;
+
+	mfiles = get_mfiles_from_menudir (dirname, NULL);
+	for (l = mfiles; l; l = l->next) {
+		MFile *mfile = l->data;
+
+		uri = g_build_filename (dirname, mfile->name, NULL);
+
+		if (mfile->verified) {
+			if (mfile->is_dir)
+				add_drawers_from_dir (uri, NULL, G_MAXINT/2, attached_toplevel_id);
+
+			else if ((g_str_has_suffix (mfile->name, ".desktop") ||
+				  g_str_has_suffix (mfile->name, ".kdelnk")) &&
+				 vfs_text_uri_exists (uri))
+				panel_launcher_create_with_id (attached_toplevel_id, G_MAXINT/2, uri);
+		}
+
+		g_free (uri);
+	}
+
+	free_mfile_list (mfiles);
+	g_free (attached_toplevel_id);
+}
+
+static void
+add_menudrawer_to_panel (GtkWidget *menuitem,
+			 MenuFinfo *mf)
+
+{
+	PanelWidget *panel;
+	PanelData   *pd;
+	int          insertion_pos;
+
+	g_return_if_fail (mf != NULL);
+	
+	panel = menu_get_panel (menuitem);
 
 	pd = g_object_get_data (G_OBJECT (panel->toplevel), "PanelData");
-	if (pd != NULL)
-		insertion_pos = pd->insertion_pos;
+	insertion_pos = pd ? pd->insertion_pos : -1;
 
-	add_drawers_from_dir (mf->menudir, mf->dir_name, insertion_pos, panel);
+	add_drawers_from_dir (mf->menudir,
+			      mf->dir_name,
+			      insertion_pos,
+			      panel_profile_get_toplevel_id (panel->toplevel));
 }
 
 static void
@@ -2414,7 +2415,6 @@ applet_menu_append (GtkWidget  *menu,
 		    gboolean objects_writable)
 {
 	GtkWidget *menuitem;
-	char      *name_with_mnemonic;
 
 	menuitem = gtk_image_menu_item_new ();
 
@@ -2422,9 +2422,7 @@ applet_menu_append (GtkWidget  *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, applet->stock_icon, applet->icon, NULL, FALSE);
 	
-	name_with_mnemonic = g_strconcat ("_", applet->name, NULL);
-	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, name_with_mnemonic, FALSE);
-	g_free (name_with_mnemonic);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, applet->name, TRUE);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2461,7 +2459,6 @@ applet_menu_append_category (GtkWidget *menu,
 			     const char *stock_icon)
 {
 	GtkWidget *menuitem;
-	char      *category_with_mnemonic;
 
 	menuitem = gtk_image_menu_item_new ();
 
@@ -2469,9 +2466,7 @@ applet_menu_append_category (GtkWidget *menu,
 		panel_load_menu_image_deferred (
 			menuitem, GTK_ICON_SIZE_MENU, stock_icon, NULL, NULL, FALSE);
 
-	category_with_mnemonic = g_strconcat ("_", category, NULL);
-	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category_with_mnemonic, FALSE);
-	g_free (category_with_mnemonic);
+	setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, category, TRUE);
 
 	gtk_widget_show_all (menuitem);
 
@@ -2785,10 +2780,10 @@ create_applets_menu (GtkWidget             *menu,
 static void
 create_new_panel (GtkWidget *menuitem)
 {
-	panel_profile_create_toplevel ();
+	panel_profile_create_toplevel (gtk_widget_get_screen (menuitem));
 }
 
-static void
+void
 setup_stock_menu_item (GtkWidget   *item,
 		       GtkIconSize  icon_size,
 		       const char  *stock_id,
@@ -2845,32 +2840,6 @@ create_distribution_menu (GtkWidget *menu,
 	return menu;
 }
 
-static GtkWidget *
-create_kde_menu (GtkWidget *menu, gboolean fake_submenus,
-		 gboolean force, gboolean fake,
-		 gboolean launcher_add)
-{
-	char *uri;
-
-	uri = gnome_vfs_get_uri_from_local_path (kde_menudir);
-
-	if (!fake || menu)
-		menu = create_menu_at (menu, 
-				       uri,
-				       launcher_add,
-				       _("KDE Menu"), 
-				       fake_submenus,
-				       force);
-	else
-		menu = create_fake_menu_at (uri,
-					    launcher_add,
-					    _("KDE Menu"));
-
-	g_free (uri);
-
-	return menu;
-}
-
 static GtkWidget *
 create_add_launcher_menu (GtkWidget *menu, gboolean fake_submenus)
 {
@@ -2894,10 +2863,6 @@ create_add_launcher_menu (GtkWidget *menu, gboolean fake_submenus)
 
 	add_distribution_submenu (menu, fake_submenus,
 				  TRUE /*launcher_add */);
-	if (g_file_test (kde_menudir, G_FILE_TEST_IS_DIR)) {
-		add_kde_submenu (menu, fake_submenus,
-				 TRUE /*launcher_add */);
-	}
 
 	return menu;
 }
@@ -3156,7 +3121,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("_Launcher..."), FALSE);
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher..."), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(ask_about_launcher_cb),NULL);
@@ -3165,7 +3130,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher _from menu"), FALSE);
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_LAUNCHER, _("Launcher from menu"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	m = create_add_launcher_menu (NULL, TRUE);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), m);
@@ -3175,7 +3140,7 @@ make_add_submenu (GtkWidget             *menu,
 
   	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_MAIN_MENU, _("Main _Menu"), FALSE);
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_MAIN_MENU, _("Main Menu"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   G_CALLBACK(add_menu_to_panel),
@@ -3185,7 +3150,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu _Bar"), FALSE);
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_GNOME_LOGO, _("Menu Bar"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (menuitem, "activate",
 			  G_CALLBACK (add_menu_bar_to_panel), NULL);
@@ -3194,7 +3159,7 @@ make_add_submenu (GtkWidget             *menu,
 
 	menuitem = gtk_image_menu_item_new ();
 	setup_stock_menu_item (
-		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("_Drawer"), FALSE);
+		menuitem, GTK_ICON_SIZE_MENU, PANEL_STOCK_DRAWER, _("Drawer"), TRUE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	g_signal_connect (G_OBJECT(menuitem), "activate",
 			   (GtkSignalFunc) add_drawer_to_panel,
@@ -3278,28 +3243,6 @@ add_distribution_submenu (GtkWidget *root_menu, gboolean fake_submenus,
 			  NULL);
 }
 
-static void
-add_kde_submenu (GtkWidget *root_menu, gboolean fake_submenus,
-		 gboolean launcher_add)
-{
-	GtkWidget *menu;
-	GtkWidget *menuitem;
-
-	menu = create_kde_menu (NULL, fake_submenus, TRUE,
-				TRUE, launcher_add);
-
-	menuitem = gtk_image_menu_item_new ();
-
-	panel_load_menu_image_deferred (
-		menuitem, panel_menu_icon_get_size (), PANEL_STOCK_KDE, NULL, NULL, FALSE);
-
-	setup_menuitem (menuitem, panel_menu_icon_get_size (), NULL, _("KDE Menu"), TRUE);
-	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
-	g_signal_connect (G_OBJECT(menu),"show",
-			  G_CALLBACK(submenu_to_display), NULL);
-}
-
 GtkWidget *
 create_root_menu (GtkWidget   *root_menu,
 		  PanelWidget *panel,
@@ -3314,17 +3257,12 @@ create_root_menu (GtkWidget   *root_menu,
 	gboolean                has_subs;
 	gboolean                has_subs2;
 
-	if ((flags & MAIN_MENU_KDE_SUB) && !got_kde_menus ())
-		flags &= ~MAIN_MENU_KDE_SUB;
-
 	if ((flags & MAIN_MENU_DISTRIBUTION_SUB) && !got_distro_menus ())
 		flags &= ~MAIN_MENU_DISTRIBUTION_SUB;
 
-	has_inline = (flags & (MAIN_MENU_SYSTEM |
-			       MAIN_MENU_KDE));
+	has_inline = (flags & MAIN_MENU_SYSTEM);
 
-	has_subs = (flags & (MAIN_MENU_SYSTEM_SUB |
-			     MAIN_MENU_KDE_SUB));
+	has_subs = (flags & MAIN_MENU_SYSTEM_SUB);
 
 	has_subs2 = (flags & (MAIN_MENU_DESKTOP_SUB |
 			      MAIN_MENU_PANEL_SUB));
@@ -3352,9 +3290,6 @@ create_root_menu (GtkWidget   *root_menu,
 		create_distribution_menu(root_menu, fake_submenus, FALSE,
 					 FALSE /* launcher_add */);
 	}
-	if (flags & MAIN_MENU_KDE)
-		create_kde_menu(root_menu, fake_submenus, FALSE, FALSE,
-				FALSE /* launcher_add */);
 
 	/*others here*/
 
@@ -3383,10 +3318,6 @@ create_root_menu (GtkWidget   *root_menu,
 		add_distribution_submenu (root_menu, fake_submenus,
 					  FALSE /*launcher_add */);
 	}
-	if (flags & MAIN_MENU_KDE_SUB) {
-		add_kde_submenu (root_menu, fake_submenus,
-				 FALSE /*launcher_add */);
-	}
 
 	if ( ! no_run_box && extra_items) {
 		add_menu_separator (root_menu);
