@@ -35,6 +35,7 @@
 #include "panel-gconf.h"
 #include "panel.h"
 #include "panel-widget.h"
+#include "panel-util.h"
 
 typedef struct {
 	GdkScreen       *screen;
@@ -666,7 +667,7 @@ panel_profile_set_attached_custom_icon (PanelToplevel *toplevel,
 
 	key = panel_profile_get_attached_object_key (toplevel, "custom_icon");
 	if (key)
-		gconf_client_set_string (client, key, custom_icon, NULL);
+		gconf_client_set_string (client, key, sure_string (custom_icon), NULL);
 }
 
 char *
@@ -1208,7 +1209,7 @@ panel_profile_background_change_notify (GConfClient   *client,
 		if (value->type == GCONF_VALUE_BOOL)
 			panel_background_set_stretch (background,
 						      gconf_value_get_bool (value));
-	} else if (!strcmp (key, "fit")) {
+	} else if (!strcmp (key, "rotate")) {
 		if (value->type == GCONF_VALUE_BOOL)
 			panel_background_set_rotate (background,
 						     gconf_value_get_bool (value));
@@ -1330,9 +1331,28 @@ panel_profile_list_is_writable (PanelGConfKeyType type)
 }
 
 void
-panel_profile_create_toplevel (void)
+panel_profile_create_toplevel (GdkScreen *screen)
 {
-	panel_profile_add_to_list (PANEL_GCONF_TOPLEVELS, NULL);
+	GConfClient *client;
+	const char  *key;
+	char        *id;
+	char        *dir;
+       
+	g_return_if_fail (screen != NULL);
+
+	client = panel_gconf_get_client ();
+
+	id = panel_profile_find_new_id (PANEL_GCONF_TOPLEVELS);
+
+	dir = g_strdup_printf (PANEL_CONFIG_DIR "/%s/toplevels/%s", current_profile, id);
+	panel_gconf_associate_schemas_in_dir (client, dir, PANEL_SCHEMAS_DIR "/toplevels");
+	g_free (dir);
+
+	key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, current_profile, id, "screen");
+	gconf_client_set_int (client, key, gdk_screen_get_number (screen), NULL);
+	
+	/* takes ownership of id */
+	panel_profile_add_to_list (PANEL_GCONF_TOPLEVELS, id);
 }
 
 static void
